Name:           gearbox
Version:        10.11
Release:        4%{?dist}
Summary:        A collection of usable peer-reviewed robotics-related libraries

Group:          Development/Libraries
License:        LGPLv2+ and GPLv2+
URL:            http://gearbox.sourceforge.net
Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
# Moves the library installation path from libdir/name to libdir
Patch0:         gearbox-9.11.fixinstallpaths.patch
# Fixes DSO-related link errors.  Not yet submitted upstream
Patch1:         gearbox-9.11.fixdso.patch
# Add detection of s390x architecture
Patch2:         gearbox-9.11.s390.patch
# Fix build errors with gcc-4.7
Patch3:         gearbox-9.11.gcc47.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  graphviz

#ice isn't present on ppc64, just require it for non ppc64 systems
%ifnarch ppc64
BuildRequires:  ice-devel

Requires:       ice
%endif


%description
Gearbox provides a collection of usable peer-reviewed robotics-related
libraries. Gearbox is not an integration framework. It provides a set
of implementations, without insisting on a standard API, for use by
any number of existing frameworks.  Gearbox includes cross-platform
libraries to communicate over TCP, UDP, and serial, and implements the
communication protocols of many popular sensors.


%package devel
Summary: Header files and libraries for %{name}
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Requires: cmake
%ifnarch ppc64
Requires: ice-devel
%endif
%description devel
Contains the header files and libraries for %{name}. 
If you like to develop programs using %{name},
you will need to install %{name}-devel.


%prep
%setup -q
# Moves shared libraries from libdir/gearbox to libdir, as per FHS standards
%patch0 -p1 -b .fixinstallpaths
%patch1 -p1 -b .fixdso
%patch2 -p1 -b .s390
%patch3 -p0 -b .gcc48

%build
%cmake \
  -DENABLE_LIB_FLEXIPORT=OFF \
  -DENABLE_LIB_BASICEXAMPLE=OFF \
  -DENABLE_LIB_GBXUTILACFR=ON \
  -DENABLE_LIB_GBXGARMINACFR=ON \
  -DENABLE_LIB_GBXSERIALACFR=ON \
  -DHOKUYO_AIST_BUILD_BINDINGS=OFF \
  -DGBX_BUILD_TESTS=ON \
  -DCMAKE_SKIP_RPATH:BOOL=ON\
%ifarch ppc64 
 -DENABLE_LIB_GBXSICKACFR=OFF\
%else
 -DENABLE_LIB_GBXSICKACFR=ON\
%endif
.

make VERBOSE=1
pushd doc
doxygen doxyfile
popd

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT

# Remove the examples that gearbox installs.  If needed
# they can be built from source contained in the datadir
rm $RPM_BUILD_ROOT%{_bindir}/*

%clean
rm -rf $RPM_BUILD_ROOT

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig


%files
%defattr(-,root,root,-)
%doc LICENSE
%{_libdir}/*.so.*

%files devel
%defattr (-,root,root,-)
%doc doc/html
%doc doc/images
%{_libdir}/*.so
%{_libdir}/%{name}
%{_includedir}/%{name}
%{_libdir}/pkgconfig/*.pc
%{_datadir}/%{name}



%changelog
* Thu Apr 04 2013 Rich Mattes <richmattes@gmail.com> - 10.11-4
- Rebuild for new ice

* Sun Feb 03 2013 Kevin Fenzi <kevin@scrye.com> - 10.11-3
- Rebuild for broken deps in rawhide

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 10.11-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jul 07 2012 Rich Mattes <richmattes@gmail.com> - 10.11-1
- Update to 10.11
- Remove flexiport and hokuyo_aist (they are in separate packages now)
- Remove flexiport and hokuyo_aist licenses from spec

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 9.11-10
- Rebuilt for c++ ABI breakage

* Wed Jan 11 2012 Rich Mattes <richmattes@gmail.com> - 9.11-9
- gcc 4.8 build error fixes

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 9.11-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sun Jun 20 2010 Dan Horák <dan[at]danny.cz> - 9.11-7
- add detection of s390x architecture

* Fri Mar 19 2010 Mary Ellen Foster <mefoster@gmail.com> - 9.11-6
- Rebuild with new Ice

* Thu Mar 11 2010 Rich Mattes <richmattes@gmail.com> - 9.11-5
- Fixed DSO related compile issues
- Removed -ice subpackage
- Fixed directory ownership
- Removed rpath
- Fixed source download URL

* Sat Feb 13 2010 Rich Mattes <richmattes@gmail.com> - 9.11-4
- Fixed pkg-config files from requiring non-existent packages

* Mon Jan 18 2010 Rich Mattes <richmattes@gmail.com> - 9.11-3
- Fixed package versioning
- Fixed sourceforge download URL
- Fixed gearbox-ice post operations

* Sat Jan 9 2010 Rich Mattes <richmattes@gmail.com> - 9.11-2
- Split libraries that use ICE into gearbox-ice subpackage
- Gearbox now builds on ppc64 without gearbox-ice subpackage

* Fri Nov 20 2009 Rich Mattes <richmattes@gmail.com> - 9.11-1
- Updated to version 9.11
- Updated package description

* Sun Nov 8 2009 Rich Mattes <richmattes@gmail.com> - 9.07-3
- Fixed cmake module install paths
- Fixed cmake file generation
- Aligned licenses with upstream
- Enabled ppc build

* Thu Oct 22 2009 Rich Mattes <richmattes@gmail.com> - 9.07-2
- Fixed library install path
- Fixed build order problem
- Fixed cmake module install path

* Wed Oct 21 2009 Rich Mattes <richmattes@gmail.com> - 9.07-1
- First build
- Fixed cmake 64 bit install paths
- Fixed license file
